<?php

if ( ! defined( 'ABSPATH' ) ) exit;
/* 
* +--------------------------------------------------------------------------+
* | Copyright (c) 2011-2024 RealSatisfied                                    |
* +--------------------------------------------------------------------------+
* | This program is free software; you can redistribute it and/or modify     |
* | it under the terms of the GNU General Public License as published by     |
* | the Free Software Foundation; either version 2 of the License, or        |
* | (at your option) any later version.                                      |
* |                                                                          |
* | This program is distributed in the hope that it will be useful,          |
* | but WITHOUT ANY WARRANTY; without even the implied warranty of           |
* | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            |
* | GNU General Public License for more details.                             |
* |                                                                          |
* | You should have received a copy of the GNU General Public License        |
* | along with this program; if not, write to the Free Software              |
* | Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA |
* +--------------------------------------------------------------------------+
*/

/*
Plugin Name: RealSatisfied Review Widget
Plugin URI: http://wordpress.org/extend/plugins/realsatisfied-review-widget/
Description: Sidebar and Footer widget that displays RealSatisfied Testimonials and Ratings data based on an Agent or Office Profile Page RSS feed.
Version: 2.0.0
Author: RealSatisfied (www.realsatisfied.com)
Text Domain: realsatisfied-review-widget
Author URI: http://www.realsatisfied.com/
License: GPLv2 or later .
License URI: http://www.gnu.org/licenses/gpl-2.0.html
*/

class RSRW_Real_Satisfied_Review_Widget extends WP_Widget {	
	function __construct(){		
		$widget_ops = array( 'classname' => 'rsw_widget', 'description' => __( 'Sidebar and Footer widget that displays RealSatisfied Testimonials and ratings data based on an Agent or Office Profile Page RSS feed.', 'realsatisfied-review-widget' ) );
		parent::__construct(false, $name = __('RealSatisfied Review Widget', 'realsatisfied-review-widget'), $widget_ops );
	}

	// Widget form creation with default values
	function form( $instance ) {
		$rsw_mode                    = isset($instance['mode'])                    ? esc_attr($instance['mode']) : '';
		$rsw_real_satisfied_id       = isset($instance['real_satisfied_id'])       ? esc_attr($instance['real_satisfied_id']) : '';
		$rsw_display_photo			 = isset($instance['display_photo'])		   ? (bool)$instance['display_photo'] : True;
		$rsw_overall_ratings         = isset($instance['show_overall_ratings'])    ? esc_attr($instance['show_overall_ratings']) : True;
        $rsw_show_rs_banner 	     = isset($instance['show_rs_banner'])          ? esc_attr($instance['show_rs_banner']) : True;
		$rsw_display_ratings         = isset($instance['display_ratings'])         ? esc_attr($instance['display_ratings']) : True;
		$rsw_show_dates 			 = isset($instance['show_dates'])              ? esc_attr($instance['show_dates']) : True;
        $rsw_auto_animate 	         = isset($instance['auto_animate'])            ? esc_attr($instance['auto_animate']) : True;
        $rsw_display_arrows          = isset($instance['display_arrows'])          ? (bool)$instance['display_arrows']: True;
		$rsw_speed 			         = isset($instance['speed'])                   ? esc_attr($instance['speed']) : 2 ;
		$rsw_animation_type          = isset($instance['animation_type'])          ? esc_attr($instance['animation_type']): 'slide';

		// Defining For Escape Function
		$mode_id = $this->get_field_id('mode'); 									$mode_name = $this->get_field_name('mode');
		$real_satisfied_id = $this->get_field_id('real_satisfied_id'); 				$real_satisfied_name = $this->get_field_name('real_satisfied_id');
		$display_photo_id = $this->get_field_id('display_photo');					$display_photo_name = $this->get_field_name('display_photo');
		$show_overall_ratings_id = $this->get_field_id('show_overall_ratings');     $show_overall_ratings_name = $this->get_field_name('show_overall_ratings');
		$show_rs_banner_id = $this->get_field_id('show_rs_banner');					$show_rs_banner_name = $this->get_field_name('show_rs_banner');
		$display_ratings_id = $this->get_field_id('display_ratings');				$display_ratings_name = $this->get_field_name('display_ratings');		
		$show_dates_id = $this->get_field_id('show_dates');							$show_dates_name = $this->get_field_name('show_dates');
		$auto_animate_id = $this->get_field_id('auto_animate');						$auto_animate_name = $this->get_field_name('auto_animate');
		$display_arrows_id = $this->get_field_id('display_arrows');         		$display_arrows_name = $this->get_field_name('display_arrows');
		$animation_type_id = $this->get_field_id('animation_type');         		$animation_type_name = $this->get_field_name('animation_type');
		$speed_id = $this->get_field_id('speed');                           		$speed_name = $this->get_field_name('speed');

		// Widget Setting Panel
		?>		
		<h3>RealSatisfied Widget Settings:</h3> 
		<p>			
			<label for="<?php echo esc_html($mode_id); ?>"><?php esc_html_e('Display Mode:', 'realsatisfied-review-widget'); ?></label>			
			<select class="widefat" id="<?php echo esc_html($mode_id); ?>" name="<?php echo esc_html($mode_name); ?>">
				<option value="" <?php echo ( empty($rsw_mode) ) ? ' selected="selected"' : ''; ?>><?php esc_html_e('Choose Display Mode', 'realsatisfied-review-widget'); ?></option>
				<option value="Agent" <?php echo ( $rsw_mode == "Agent" ) ? ' selected="selected"' : '' ; ?>>Agent</option>
				<option value="Office" <?php echo ( $rsw_mode == 'Office' ) ? ' selected="selected"' : '' ; ?>>Office</option>
			</select>
		</p>
		<p>
			<label for="<?php echo esc_html($real_satisfied_id); ?>"><?php esc_html_e('Vanity Key:', 'realsatisfied-review-widget'); ?></label>
			<input class="widefat" id="<?php echo esc_html($real_satisfied_id); ?>" name="<?php echo esc_html($real_satisfied_name) ; ?>" type="text" value="<?php echo esc_attr($rsw_real_satisfied_id); ?>" />
	    </p>		
		
		<h3>Layout and Setting</h3>
		<h3>Header</h3>
		<p>
			<input class="checkbox" type="checkbox" id="<?php echo esc_html($display_photo_id); ?>" name="<?php echo esc_html($display_photo_name); ?>" <?php checked($rsw_display_photo); ?> />
			<label for="<?php echo esc_html($display_photo_id); ?>">Display Profile Photo</label>
		</p>

		<p>
			<input class="checkbox" type="checkbox"  id="<?php echo esc_html($show_overall_ratings_id); ?>" name="<?php echo esc_html($show_overall_ratings_name); ?>"<?php if ($rsw_overall_ratings) { ?> checked="checked"<?php } ?> />
			<label for="<?php echo esc_html($show_overall_ratings_id); ?>">Show Overall Rating</label>
		</p>

		<h3>Footer</h3>
		<p>
			<input class="checkbox" type="checkbox"  id="<?php echo esc_html($show_rs_banner_id); ?>" name="<?php echo esc_html($show_rs_banner_name); ?>"<?php if ($rsw_show_rs_banner) { ?> checked="checked"<?php } ?> />
			<label for="<?php echo esc_html($show_rs_banner_id); ?>">Display RealSatisfied Banner</label>
		</p>
		
		<h3>Testimonials</h3>
		<p>
			<input class="checkbox" type="checkbox"  id="<?php echo esc_html($display_ratings_id); ?>" name="<?php echo esc_html($display_ratings_name); ?>"<?php if ($rsw_display_ratings) { ?> checked="checked"<?php } ?> /> 
			<label for="<?php echo esc_html($display_ratings_id); ?>">Display Client Ratings</label>
		</p>
		<p>
			<input class="checkbox" type="checkbox"  id="<?php echo esc_html($show_dates_id); ?>" name="<?php echo esc_html($show_dates_name); ?>"<?php if ($rsw_show_dates) { ?> checked="checked"<?php } ?> />
			<label for="<?php echo esc_html($show_dates_id); ?>">Display Date for Testimonials</label>
		</p>
		<p>
			<input class="checkbox" type="checkbox"  id="<?php echo esc_html($auto_animate_id); ?>" name="<?php echo esc_html($auto_animate_name); ?>"<?php if ($rsw_auto_animate) { ?> checked="checked"<?php } ?> />
			<label for="<?php echo esc_html($auto_animate_id); ?>">Animate Automatically</label>
		</p>
		<p>
			<input class="checkbox" type="checkbox"  id="<?php echo esc_html($display_arrows_id); ?>" name="<?php echo esc_html($display_arrows_name); ?>"<?php if ($rsw_display_arrows) { ?> checked="checked"<?php } ?> />
			<label for="<?php echo esc_html($display_arrows_id); ?>">Display Side Arrows</label>
		</p>
		<p>
			<label for="<?php echo esc_html($speed_id); ?>"><?php esc_html_e('Hold each slide for:', 'realsatisfied-review-widget'); ?></label>
			<select class="widefat" id="<?php echo esc_html($speed_id); ?>" name="<?php echo esc_html($speed_name); ?>">
				<?php
				for($i=2; $i<16; $i++) {
					echo '<option value="' .esc_attr($i) . '"' . ( $i == $instance['speed'] ? ' selected="selected"' : '' ) . '>' .esc_html($i . " seconds") ."</option>\n";
				}
				?>
			</select>
		</p>
		<p>
			<label for="<?php echo esc_html($animation_type_id); ?>"><?php esc_html_e('Animation Type:', 'realsatisfied-review-widget'); ?></label>
			<select class="widefat" id="<?php echo esc_html($animation_type_id); ?>" name="<?php echo esc_html($animation_type_name); ?>">
				<option value="slide" <?php echo ( $rsw_animation_type == 'slide' ) ? ' selected="selected"' : '' ; ?>>Slide</option>
				<option value="fade" <?php echo ( $rsw_animation_type == 'fade' ) ? ' selected="selected"' : '' ; ?>>Fade</option>
			</select>
		</p>						
		<hr style="width: 80%; margin: 20px auto; border: 1px solid #ccc;"> 
		<p>
			<?php rsrw_clear_cache_button(); ?>
		</p>
		<?php
	}

	function update( $new_instance, $old_instance) {
		$instance = $old_instance;
	
		$instance['mode'] 					= sanitize_text_field( $new_instance['mode'] );
		$instance['real_satisfied_id'] 		= sanitize_text_field( $new_instance['real_satisfied_id'] );		
		$instance['display_photo'] 			= !empty($new_instance['display_photo']) ? 1 : 0;    
		$instance['show_overall_ratings'] 	= !empty($new_instance['show_overall_ratings']) ? 1 : 0;
		$instance['show_rs_banner'] 		= !empty($new_instance['show_rs_banner']) ? 1 : 0;
		$instance['display_ratings'] 		= !empty($new_instance['display_ratings']) ? 1 : 0;
		$instance['show_dates'] 			= !empty($new_instance['show_dates']) ? 1 : 0;
		$instance['auto_animate'] 			= !empty($new_instance['auto_animate']) ? 1 : 0;
		$instance['display_arrows'] 		= !empty($new_instance['display_arrows']) ? 1 : 0;	
		$instance['speed'] 					= intval( $new_instance['speed'] );
		$instance['animation_type'] 		= sanitize_text_field( $new_instance['animation_type'] );
	
		return $instance;
	}

	// widget display on sidebar
	function widget( $args, $instance ) {		
		extract( $args );
		
		if ( $instance['real_satisfied_id'] ) {	
            // Define feed source URLs as variables
			$agent_feed_source   =  'https://rss.realsatisfied.com/rss/v3/agent/detailed/';
			$office_feed_source  =  'https://rss.realsatisfied.com/rss/v3/office/';
			$agent_namespace     =  'https://rss.realsatisfied.com/ns/realsatisfied/';
			$office_namespace    =  'https://rss.realsatisfied.com/ns/realsatisfied/';

			// Set RSS feed source based on mode
			$rsw_rss_feed_source = fetch_feed(($instance['mode'] == "Agent" ? $agent_feed_source . $instance['real_satisfied_id'] : $office_feed_source . $instance['real_satisfied_id']) . '/page=1&source=wp_widget');

			if ( !is_wp_error( $rsw_rss_feed_source ) ) { 
				$rsw_maxitems = $rsw_rss_feed_source->get_item_quantity(50);
				$rsw_rss_items = $rsw_rss_feed_source->get_items(0, $rsw_maxitems);
    			
				// Initialize arrays for storing channel and testimonials data
    			$rsw_channel_array = array('link' => $rsw_rss_feed_source->get_link());
    			$rsw_testimonials_array = array();

				// Agent Mode
				if ($instance['mode'] == "Agent") {
					$rsw_channel_array['overall_satisfaction'] = rsrw_obtain_channel_tag_data($rsw_rss_feed_source, $agent_namespace, 'overall_satisfaction');
					$rsw_channel_array['recommendation_rating'] = rsrw_obtain_channel_tag_data($rsw_rss_feed_source, $agent_namespace, 'recommendation_rating');
					$rsw_channel_array['performance_rating'] = rsrw_obtain_channel_tag_data($rsw_rss_feed_source, $agent_namespace, 'performance_rating');
					$rsw_channel_array['response_count'] = rsrw_obtain_channel_tag_data($rsw_rss_feed_source, $agent_namespace, 'responseCount');
					$rsw_channel_array['avatar'] = rsrw_obtain_channel_tag_data($rsw_rss_feed_source, $agent_namespace, 'avatar');
					
					$overall_satisfaction = $rsw_channel_array['overall_satisfaction'];
    				$recommendation_rating = $rsw_channel_array['recommendation_rating'];
    				$performance_rating = $rsw_channel_array['performance_rating'];
    				$rsw_response_count = $rsw_channel_array['response_count'];
    				$rsw_avatar = $rsw_channel_array['avatar'];
				} else {
					$rsw_channel_array['office'] = rsrw_obtain_channel_tag_data($rsw_rss_feed_source, $office_namespace, 'office');
        			$rsw_channel_array['logo'] = rsrw_obtain_channel_tag_data($rsw_rss_feed_source, $office_namespace, 'logo');
        			$rsw_channel_array['overall_satisfaction'] = rsrw_obtain_channel_tag_data($rsw_rss_feed_source, $office_namespace, 'overall_satisfaction');
        			$rsw_channel_array['recommendation_rating'] = rsrw_obtain_channel_tag_data($rsw_rss_feed_source, $office_namespace, 'recommendation_rating');
        			$rsw_channel_array['performance_rating'] = rsrw_obtain_channel_tag_data($rsw_rss_feed_source, $office_namespace, 'performance_rating');
        			$rsw_channel_array['response_count'] = rsrw_obtain_channel_tag_data($rsw_rss_feed_source, $office_namespace, 'responseCount');
       
        			$overall_satisfaction = $rsw_channel_array['overall_satisfaction'];
        			$recommendation_rating = $rsw_channel_array['recommendation_rating'];
        			$performance_rating = $rsw_channel_array['performance_rating'];
        			$rsw_response_count = $rsw_channel_array['response_count'];
        			$office = $rsw_channel_array['office'];
        			$logo = $rsw_channel_array['logo'];
				}
				// Load testimonials items based on mode
				foreach ($rsw_rss_items as $rsw_rss_item) { 
					$rsw_testimonial_array = array(
						'title' => $rsw_rss_item->get_title(),
						'customer_type' => rsrw_obtain_item_tag_data($rsw_rss_item, $instance['mode'] == "Agent" ? $agent_namespace : $office_namespace, 'customer_type'),
						'pubDate' => rsrw_obtain_item_tag_data($rsw_rss_item, '', 'pubDate'),
						'description' => $rsw_rss_item->get_description(),
						'satisfaction' => rsrw_obtain_item_tag_data($rsw_rss_item, $instance['mode'] == "Agent" ? $agent_namespace : $office_namespace, 'satisfaction'),
						'recommendation' => rsrw_obtain_item_tag_data($rsw_rss_item, $instance['mode'] == "Agent" ? $agent_namespace : $office_namespace, 'recommendation'),
						'performance' => rsrw_obtain_item_tag_data($rsw_rss_item, $instance['mode'] == "Agent" ? $agent_namespace : $office_namespace, 'performance')
					);			
					// Additional fields for Office mode
					if ($instance['mode'] != "Agent") {
						$rsw_testimonial_array['display_name'] = rsrw_obtain_item_tag_data($rsw_rss_item, $office_namespace, 'display_name');
						$rsw_testimonial_array['avatar'] = rsrw_obtain_item_tag_data($rsw_rss_item, $office_namespace, 'avatar', '');
					}			
					$rsw_testimonials_array[] = $rsw_testimonial_array;
				}
				
				// Shuffle testimonials for Office
				if ($instance['mode'] != "Agent") {
					shuffle($rsw_testimonials_array);
				}
				// Check responseCount 
				if (!$rsw_channel_array['response_count']) {
					echo "<!-- ratings_off -->";
				} elseif ($rsw_channel_array['response_count'] == 0) {
					echo "<!-- no_results -->";
				} else {
					echo "<!-- responses :". esc_html($rsw_channel_array['response_count'])." -->";
				}
				// Testimonials
				if ( count( $rsw_testimonials_array ) == 0 ) {
					 echo "<!-- no_testimonials -->"; // NO TESTIMONIALS
				} 
				else {
					echo wp_kses_post( $before_widget );
					if ( $rsw_response_count && $rsw_response_count > 0 ) {
						// Agent Mode
						if( $instance['mode']== "Agent" ) {  
							$rating_score = number_format((($overall_satisfaction + $recommendation_rating + $performance_rating) / 60), 1);							 
							echo '<div class="header">';		 														
								if (!empty($instance['display_photo'])) {
									$web_img_path = "images.realsatisfied.com";
									if (strpos($rsw_avatar, $web_img_path) !== false) {
										echo '<img src="' . esc_url($rsw_avatar) . '" alt="Agent Avatar" class="agent-avatar"/>';
									} else {									
									$avatar_url = 'https://secure.realsatisfied.com/' . $rsw_avatar;
									echo '<img src="' . esc_url($avatar_url) . '" alt="Agent Avatar" class="agent-avatar"/>';
									}
								}																
								if ($instance['show_overall_ratings'] == True) {
									echo '<p class="profile-ratings">' . esc_html($rating_score) . '</p>'; 
									echo '<div class="overall_star_rating">';
											echo '<svg viewBox="0 0 80 16" class="overall-rating-stars-gray">';
												echo '    <path fill="#A0A0A0" d="M6.00682 0.92556C6.25927 0.16202 7.35844 0.162021 7.61088 0.92556L8.51285 3.65365C8.62575 3.99511 8.94954 4.2263 9.31488 4.2263H12.2337C13.0506 4.2263 13.3903 5.25364 12.7294 5.72553L10.368 7.41159C10.0724 7.62262 9.94877 7.99669 10.0617 8.33816L10.9636 11.0663C11.2161 11.8298 10.3268 12.4647 9.66592 11.9928L7.30453 10.3068C7.00897 10.0957 6.60874 10.0957 6.31317 10.3068L3.95178 11.9928C3.29087 12.4647 2.40162 11.8298 2.65407 11.0662L3.55604 8.33816C3.66894 7.99669 3.54526 7.62262 3.24969 7.41159L0.888301 5.72553C0.227393 5.25364 0.567055 4.2263 1.38398 4.2263H4.30282C4.66816 4.2263 4.99195 3.99511 5.10485 3.65365L6.00682 0.92556Z" />';    
												echo '    <path fill="#A0A0A0" d="M22.7822 0.92556C23.0347 0.16202 24.1338 0.162021 24.3863 0.92556L25.2882 3.65365C25.4011 3.99511 25.7249 4.2263 26.0903 4.2263H29.0091C29.826 4.2263 30.1657 5.25364 29.5048 5.72553L27.1434 7.41159C26.8478 7.62262 26.7242 7.99669 26.8371 8.33816L27.739 11.0662C27.9915 11.8298 27.1022 12.4647 26.4413 11.9928L24.0799 10.3068C23.7844 10.0957 23.3841 10.0957 23.0886 10.3068L20.7272 11.9928C20.0663 12.4647 19.177 11.8298 19.4295 11.0662L20.3314 8.33816C20.4443 7.99669 20.3206 7.62262 20.0251 7.41159L17.6637 5.72553C17.0028 5.25364 17.3424 4.2263 18.1594 4.2263H21.0782C21.4436 4.2263 21.7673 3.99511 21.8802 3.65365L22.7822 0.92556Z" />';
												echo '    <path fill="#A0A0A0" d="M39.5586 0.92556C39.811 0.16202 40.9102 0.162021 41.1626 0.92556L42.0646 3.65365C42.1775 3.99511 42.5013 4.2263 42.8666 4.2263H45.7855C46.6024 4.2263 46.9421 5.25364 46.2812 5.72553L43.9198 7.41159C43.6242 7.62262 43.5005 7.99669 43.6134 8.33816L44.5154 11.0662C44.7678 11.8298 43.8786 12.4647 43.2177 11.9928L40.8563 10.3068C40.5607 10.0957 40.1605 10.0957 39.8649 10.3068L37.5035 11.9928C36.8426 12.4647 35.9534 11.8298 36.2058 11.0662L37.1078 8.33816C37.2207 7.99669 37.097 7.62262 36.8014 7.41159L34.4401 5.72553C33.7792 5.25364 34.1188 4.2263 34.9357 4.2263H37.8546C38.2199 4.2263 38.5437 3.99511 38.6566 3.65365L39.5586 0.92556Z" />';
												echo '    <path fill="#A0A0A0" d="M56.334 0.92556C56.5864 0.16202 57.6856 0.162021 57.938 0.92556L58.84 3.65365C58.9529 3.99511 59.2767 4.2263 59.642 4.2263H62.5609C63.3778 4.2263 63.7175 5.25364 63.0565 5.72553L60.6952 7.41159C60.3996 7.62262 60.2759 7.99669 60.3888 8.33816L61.2908 11.0662C61.5432 11.8298 60.654 12.4647 59.9931 11.9928L57.6317 10.3068C57.3361 10.0957 56.9359 10.0957 56.6403 10.3068L54.2789 11.9928C53.618 12.4647 52.7288 11.8298 52.9812 11.0662L53.8832 8.33816C53.9961 7.99669 53.8724 7.62262 53.5768 7.41159L51.2154 5.72553C50.5545 5.25364 50.8942 4.2263 51.7111 4.2263H54.63C54.9953 4.2263 55.3191 3.99511 55.432 3.65365L56.334 0.92556Z" />';
												echo '    <path fill="#A0A0A0" d="M73.1103 0.92556C73.3628 0.16202 74.462 0.162021 74.7144 0.92556L75.6164 3.65365C75.7293 3.99511 76.0531 4.2263 76.4184 4.2263H79.3372C80.1542 4.2263 80.4938 5.25364 79.8329 5.72553L77.4715 7.41159C77.176 7.62262 77.0523 7.99669 77.1652 8.33816L78.0672 11.0662C78.3196 11.8298 77.4303 12.4647 76.7694 11.9928L74.408 10.3068C74.1125 10.0957 73.7123 10.0957 73.4167 10.3068L71.0553 11.9928C70.3944 12.4647 69.5051 11.8298 69.7576 11.0662L70.6596 8.33816C70.7725 7.99669 70.6488 7.62262 70.3532 7.41159L67.9918 5.72553C67.3309 5.25364 67.6706 4.2263 68.4875 4.2263H71.4063C71.7717 4.2263 72.0955 3.99511 72.2084 3.65365L73.1103 0.92556Z" />';
											echo '</svg>';
											echo '<div class="overall-rating-stars-gold" data-star="' . number_format($rating_score, 1) . '">';
												echo '<svg viewBox="0 0 80 16" class="overall-rating-stars-gold">';
													echo '    <path fill="#F0B64F" d="M6.00682 0.92556C6.25927 0.16202 7.35844 0.162021 7.61088 0.92556L8.51285 3.65365C8.62575 3.99511 8.94954 4.2263 9.31488 4.2263H12.2337C13.0506 4.2263 13.3903 5.25364 12.7294 5.72553L10.368 7.41159C10.0724 7.62262 9.94877 7.99669 10.0617 8.33816L10.9636 11.0663C11.2161 11.8298 10.3268 12.4647 9.66592 11.9928L7.30453 10.3068C7.00897 10.0957 6.60874 10.0957 6.31317 10.3068L3.95178 11.9928C3.29087 12.4647 2.40162 11.8298 2.65407 11.0662L3.55604 8.33816C3.66894 7.99669 3.54526 7.62262 3.24969 7.41159L0.888301 5.72553C0.227393 5.25364 0.567055 4.2263 1.38398 4.2263H4.30282C4.66816 4.2263 4.99195 3.99511 5.10485 3.65365L6.00682 0.92556Z" />';
													echo '     <path fill="#F0B64F" d="M22.7822 0.92556C23.0347 0.16202 24.1338 0.162021 24.3863 0.92556L25.2882 3.65365C25.4011 3.99511 25.7249 4.2263 26.0903 4.2263H29.0091C29.826 4.2263 30.1657 5.25364 29.5048 5.72553L27.1434 7.41159C26.8478 7.62262 26.7242 7.99669 26.8371 8.33816L27.739 11.0662C27.9915 11.8298 27.1022 12.4647 26.4413 11.9928L24.0799 10.3068C23.7844 10.0957 23.3841 10.0957 23.0886 10.3068L20.7272 11.9928C20.0663 12.4647 19.177 11.8298 19.4295 11.0662L20.3314 8.33816C20.4443 7.99669 20.3206 7.62262 20.0251 7.41159L17.6637 5.72553C17.0028 5.25364 17.3424 4.2263 18.1594 4.2263H21.0782C21.4436 4.2263 21.7673 3.99511 21.8802 3.65365L22.7822 0.92556Z" />';
													echo '    <path fill="#F0B64F" d="M39.5586 0.92556C39.811 0.16202 40.9102 0.162021 41.1626 0.92556L42.0646 3.65365C42.1775 3.99511 42.5013 4.2263 42.8666 4.2263H45.7855C46.6024 4.2263 46.9421 5.25364 46.2812 5.72553L43.9198 7.41159C43.6242 7.62262 43.5005 7.99669 43.6134 8.33816L44.5154 11.0662C44.7678 11.8298 43.8786 12.4647 43.2177 11.9928L40.8563 10.3068C40.5607 10.0957 40.1605 10.0957 39.8649 10.3068L37.5035 11.9928C36.8426 12.4647 35.9534 11.8298 36.2058 11.0662L37.1078 8.33816C37.2207 7.99669 37.097 7.62262 36.8014 7.41159L34.4401 5.72553C33.7792 5.25364 34.1188 4.2263 34.9357 4.2263H37.8546C38.2199 4.2263 38.5437 3.99511 38.6566 3.65365L39.5586 0.92556Z" />';
													echo '    <path fill="#F0B64F" d="M56.334 0.92556C56.5864 0.16202 57.6856 0.162021 57.938 0.92556L58.84 3.65365C58.9529 3.99511 59.2767 4.2263 59.642 4.2263H62.5609C63.3778 4.2263 63.7175 5.25364 63.0565 5.72553L60.6952 7.41159C60.3996 7.62262 60.2759 7.99669 60.3888 8.33816L61.2908 11.0662C61.5432 11.8298 60.654 12.4647 59.9931 11.9928L57.6317 10.3068C57.3361 10.0957 56.9359 10.0957 56.6403 10.3068L54.2789 11.9928C53.618 12.4647 52.7288 11.8298 52.9812 11.0662L53.8832 8.33816C53.9961 7.99669 53.8724 7.62262 53.5768 7.41159L51.2154 5.72553C50.5545 5.25364 50.8942 4.2263 51.7111 4.2263H54.63C54.9953 4.2263 55.3191 3.99511 55.432 3.65365L56.334 0.92556Z" />';
													echo '    <path fill="#F0B64F" d="M73.1103 0.92556C73.3628 0.16202 74.462 0.162021 74.7144 0.92556L75.6164 3.65365C75.7293 3.99511 76.0531 4.2263 76.4184 4.2263H79.3372C80.1542 4.2263 80.4938 5.25364 79.8329 5.72553L77.4715 7.41159C77.176 7.62262 77.0523 7.99669 77.1652 8.33816L78.0672 11.0662C78.3196 11.8298 77.4303 12.4647 76.7694 11.9928L74.408 10.3068C74.1125 10.0957 73.7123 10.0957 73.4167 10.3068L71.0553 11.9928C70.3944 12.4647 69.5051 11.8298 69.7576 11.0662L70.6596 8.33816C70.7725 7.99669 70.6488 7.62262 70.3532 7.41159L67.9918 5.72553C67.3309 5.25364 67.6706 4.2263 68.4875 4.2263H71.4063C71.7717 4.2263 72.0955 3.99511 72.2084 3.65365L73.1103 0.92556Z" />';
												echo '</svg>';
											echo '</div>';
									echo '</div>';
								}
								$tmp = $rsw_rss_feed_source->get_channel_tags($agent_namespace , 'display_name');
								$tmp = $tmp[0]; $display_name = $tmp['data'];
								echo '<a href="' . esc_url($rsw_channel_array['link']) . '" target="_blank" class="profile-reviews" title="View the Agent Profile for ' . esc_attr($display_name) . '" style="text-decoration: underline;">';
								echo '<span itemprop="itemreviewed">' . esc_html($rsw_response_count) . '</span> reviews';
								echo '</a>';
							echo '</div>';
						    echo '<div class="rsw-flexslider">';
						    	echo '<ul class="rs-slides">';						    
						     
						    	$count = 0;
						    	for ($x = 0; $x < count($rsw_testimonials_array); $x++) {
                            	$count++;
                            	$rsw_testimonial_item = $rsw_testimonials_array[$x];
                            	?>
                            	<li style="text-align: left;">
						    		<div class="testimonial">									
										<div class="name_customer_type">
											<?php echo esc_html($rsw_testimonial_item["title"]); ?>
											<span><?php echo esc_html($rsw_testimonial_item["customer_type"]); ?></span>
										</div>						    	    
						    				<?php if ($instance['display_ratings'] == true) : ?>
												<?php
												$satisfaction = $rsw_testimonial_item['satisfaction'];
    											$performance = $rsw_testimonial_item['performance'];
    											$recommendation = $rsw_testimonial_item['recommendation'];
    											$overall_rating = number_format((($satisfaction + $recommendation + $performance) / 60), 1);
    											?>
												<?php if ($overall_rating > 0) : ?>
													<div class="rating">
														<?php
														echo '<p class="testimonials-profile-ratings">' . esc_html($overall_rating) . '</p>';
														echo '<div class="star-rating-testimonial">';
															echo '<div class="survey_measure_stars">';								
																echo '<svg viewBox="0 0 80 16" class="overall-rating-stars-gray">';
																	echo '    <path fill="#A0A0A0" d="M6.00682 0.92556C6.25927 0.16202 7.35844 0.162021 7.61088 0.92556L8.51285 3.65365C8.62575 3.99511 8.94954 4.2263 9.31488 4.2263H12.2337C13.0506 4.2263 13.3903 5.25364 12.7294 5.72553L10.368 7.41159C10.0724 7.62262 9.94877 7.99669 10.0617 8.33816L10.9636 11.0663C11.2161 11.8298 10.3268 12.4647 9.66592 11.9928L7.30453 10.3068C7.00897 10.0957 6.60874 10.0957 6.31317 10.3068L3.95178 11.9928C3.29087 12.4647 2.40162 11.8298 2.65407 11.0662L3.55604 8.33816C3.66894 7.99669 3.54526 7.62262 3.24969 7.41159L0.888301 5.72553C0.227393 5.25364 0.567055 4.2263 1.38398 4.2263H4.30282C4.66816 4.2263 4.99195 3.99511 5.10485 3.65365L6.00682 0.92556Z" />';    
																	echo '    <path fill="#A0A0A0" d="M22.7822 0.92556C23.0347 0.16202 24.1338 0.162021 24.3863 0.92556L25.2882 3.65365C25.4011 3.99511 25.7249 4.2263 26.0903 4.2263H29.0091C29.826 4.2263 30.1657 5.25364 29.5048 5.72553L27.1434 7.41159C26.8478 7.62262 26.7242 7.99669 26.8371 8.33816L27.739 11.0662C27.9915 11.8298 27.1022 12.4647 26.4413 11.9928L24.0799 10.3068C23.7844 10.0957 23.3841 10.0957 23.0886 10.3068L20.7272 11.9928C20.0663 12.4647 19.177 11.8298 19.4295 11.0662L20.3314 8.33816C20.4443 7.99669 20.3206 7.62262 20.0251 7.41159L17.6637 5.72553C17.0028 5.25364 17.3424 4.2263 18.1594 4.2263H21.0782C21.4436 4.2263 21.7673 3.99511 21.8802 3.65365L22.7822 0.92556Z" />';
																	echo '    <path fill="#A0A0A0" d="M39.5586 0.92556C39.811 0.16202 40.9102 0.162021 41.1626 0.92556L42.0646 3.65365C42.1775 3.99511 42.5013 4.2263 42.8666 4.2263H45.7855C46.6024 4.2263 46.9421 5.25364 46.2812 5.72553L43.9198 7.41159C43.6242 7.62262 43.5005 7.99669 43.6134 8.33816L44.5154 11.0662C44.7678 11.8298 43.8786 12.4647 43.2177 11.9928L40.8563 10.3068C40.5607 10.0957 40.1605 10.0957 39.8649 10.3068L37.5035 11.9928C36.8426 12.4647 35.9534 11.8298 36.2058 11.0662L37.1078 8.33816C37.2207 7.99669 37.097 7.62262 36.8014 7.41159L34.4401 5.72553C33.7792 5.25364 34.1188 4.2263 34.9357 4.2263H37.8546C38.2199 4.2263 38.5437 3.99511 38.6566 3.65365L39.5586 0.92556Z" />';
																	echo '    <path fill="#A0A0A0" d="M56.334 0.92556C56.5864 0.16202 57.6856 0.162021 57.938 0.92556L58.84 3.65365C58.9529 3.99511 59.2767 4.2263 59.642 4.2263H62.5609C63.3778 4.2263 63.7175 5.25364 63.0565 5.72553L60.6952 7.41159C60.3996 7.62262 60.2759 7.99669 60.3888 8.33816L61.2908 11.0662C61.5432 11.8298 60.654 12.4647 59.9931 11.9928L57.6317 10.3068C57.3361 10.0957 56.9359 10.0957 56.6403 10.3068L54.2789 11.9928C53.618 12.4647 52.7288 11.8298 52.9812 11.0662L53.8832 8.33816C53.9961 7.99669 53.8724 7.62262 53.5768 7.41159L51.2154 5.72553C50.5545 5.25364 50.8942 4.2263 51.7111 4.2263H54.63C54.9953 4.2263 55.3191 3.99511 55.432 3.65365L56.334 0.92556Z" />';
																	echo '    <path fill="#A0A0A0" d="M73.1103 0.92556C73.3628 0.16202 74.462 0.162021 74.7144 0.92556L75.6164 3.65365C75.7293 3.99511 76.0531 4.2263 76.4184 4.2263H79.3372C80.1542 4.2263 80.4938 5.25364 79.8329 5.72553L77.4715 7.41159C77.176 7.62262 77.0523 7.99669 77.1652 8.33816L78.0672 11.0662C78.3196 11.8298 77.4303 12.4647 76.7694 11.9928L74.408 10.3068C74.1125 10.0957 73.7123 10.0957 73.4167 10.3068L71.0553 11.9928C70.3944 12.4647 69.5051 11.8298 69.7576 11.0662L70.6596 8.33816C70.7725 7.99669 70.6488 7.62262 70.3532 7.41159L67.9918 5.72553C67.3309 5.25364 67.6706 4.2263 68.4875 4.2263H71.4063C71.7717 4.2263 72.0955 3.99511 72.2084 3.65365L73.1103 0.92556Z" />';
																echo '</svg>';
																echo '<div class="overall-rating-stars-gold" data-star="' . number_format($overall_rating, 1) . '">';
																	echo '<svg viewBox="0 0 80 16" class="overall-rating-stars-gold">';
																		echo '    <path fill="#F0B64F" d="M6.00682 0.92556C6.25927 0.16202 7.35844 0.162021 7.61088 0.92556L8.51285 3.65365C8.62575 3.99511 8.94954 4.2263 9.31488 4.2263H12.2337C13.0506 4.2263 13.3903 5.25364 12.7294 5.72553L10.368 7.41159C10.0724 7.62262 9.94877 7.99669 10.0617 8.33816L10.9636 11.0663C11.2161 11.8298 10.3268 12.4647 9.66592 11.9928L7.30453 10.3068C7.00897 10.0957 6.60874 10.0957 6.31317 10.3068L3.95178 11.9928C3.29087 12.4647 2.40162 11.8298 2.65407 11.0662L3.55604 8.33816C3.66894 7.99669 3.54526 7.62262 3.24969 7.41159L0.888301 5.72553C0.227393 5.25364 0.567055 4.2263 1.38398 4.2263H4.30282C4.66816 4.2263 4.99195 3.99511 5.10485 3.65365L6.00682 0.92556Z" />';
																		echo '     <path fill="#F0B64F" d="M22.7822 0.92556C23.0347 0.16202 24.1338 0.162021 24.3863 0.92556L25.2882 3.65365C25.4011 3.99511 25.7249 4.2263 26.0903 4.2263H29.0091C29.826 4.2263 30.1657 5.25364 29.5048 5.72553L27.1434 7.41159C26.8478 7.62262 26.7242 7.99669 26.8371 8.33816L27.739 11.0662C27.9915 11.8298 27.1022 12.4647 26.4413 11.9928L24.0799 10.3068C23.7844 10.0957 23.3841 10.0957 23.0886 10.3068L20.7272 11.9928C20.0663 12.4647 19.177 11.8298 19.4295 11.0662L20.3314 8.33816C20.4443 7.99669 20.3206 7.62262 20.0251 7.41159L17.6637 5.72553C17.0028 5.25364 17.3424 4.2263 18.1594 4.2263H21.0782C21.4436 4.2263 21.7673 3.99511 21.8802 3.65365L22.7822 0.92556Z" />';
																		echo '    <path fill="#F0B64F" d="M39.5586 0.92556C39.811 0.16202 40.9102 0.162021 41.1626 0.92556L42.0646 3.65365C42.1775 3.99511 42.5013 4.2263 42.8666 4.2263H45.7855C46.6024 4.2263 46.9421 5.25364 46.2812 5.72553L43.9198 7.41159C43.6242 7.62262 43.5005 7.99669 43.6134 8.33816L44.5154 11.0662C44.7678 11.8298 43.8786 12.4647 43.2177 11.9928L40.8563 10.3068C40.5607 10.0957 40.1605 10.0957 39.8649 10.3068L37.5035 11.9928C36.8426 12.4647 35.9534 11.8298 36.2058 11.0662L37.1078 8.33816C37.2207 7.99669 37.097 7.62262 36.8014 7.41159L34.4401 5.72553C33.7792 5.25364 34.1188 4.2263 34.9357 4.2263H37.8546C38.2199 4.2263 38.5437 3.99511 38.6566 3.65365L39.5586 0.92556Z" />';
																		echo '    <path fill="#F0B64F" d="M56.334 0.92556C56.5864 0.16202 57.6856 0.162021 57.938 0.92556L58.84 3.65365C58.9529 3.99511 59.2767 4.2263 59.642 4.2263H62.5609C63.3778 4.2263 63.7175 5.25364 63.0565 5.72553L60.6952 7.41159C60.3996 7.62262 60.2759 7.99669 60.3888 8.33816L61.2908 11.0662C61.5432 11.8298 60.654 12.4647 59.9931 11.9928L57.6317 10.3068C57.3361 10.0957 56.9359 10.0957 56.6403 10.3068L54.2789 11.9928C53.618 12.4647 52.7288 11.8298 52.9812 11.0662L53.8832 8.33816C53.9961 7.99669 53.8724 7.62262 53.5768 7.41159L51.2154 5.72553C50.5545 5.25364 50.8942 4.2263 51.7111 4.2263H54.63C54.9953 4.2263 55.3191 3.99511 55.432 3.65365L56.334 0.92556Z" />';
																		echo '    <path fill="#F0B64F" d="M73.1103 0.92556C73.3628 0.16202 74.462 0.162021 74.7144 0.92556L75.6164 3.65365C75.7293 3.99511 76.0531 4.2263 76.4184 4.2263H79.3372C80.1542 4.2263 80.4938 5.25364 79.8329 5.72553L77.4715 7.41159C77.176 7.62262 77.0523 7.99669 77.1652 8.33816L78.0672 11.0662C78.3196 11.8298 77.4303 12.4647 76.7694 11.9928L74.408 10.3068C74.1125 10.0957 73.7123 10.0957 73.4167 10.3068L71.0553 11.9928C70.3944 12.4647 69.5051 11.8298 69.7576 11.0662L70.6596 8.33816C70.7725 7.99669 70.6488 7.62262 70.3532 7.41159L67.9918 5.72553C67.3309 5.25364 67.6706 4.2263 68.4875 4.2263H71.4063C71.7717 4.2263 72.0955 3.99511 72.2084 3.65365L73.1103 0.92556Z" />';
																	echo '</svg>';
																echo '</div>';
															echo '</div>';
														echo'</div>';
														?>
														<!-- Dropdown -->
														<div class="survey_overall_dropdown">
															<a class="dropdown-icon" href="#" role="button" data-bs-toggle="dropdown" data-bs-trigger="dropdown" aria-expanded="false"> </a>
																<ul class="dropdown-menu">
																	<?php
																	$metrics = ['Satisfaction' => $satisfaction,'Performance' => $performance,'Recommendation' => $recommendation];
																	foreach ($metrics as $label => $metric) {
																		list($score) = rsrw_rating_star_score($metric);															
																		$li_agent = "<li> <div class='banner-rating d-flex justify-content-between align-items-center'> 
																					<div class='survey_measure_text'>{$label}</div>
																					<div class='score'>
																					<span class='survey_measure_rating'>{$score}</span>
																					</div>
																				<div class='dropdown_stars'>";
																					echo wp_kses_post($li_agent);
																					echo '<div>' . wp_kses_post( rsrw_obtain_single_gold_star() ) . '</div>';
																					echo "</div>
																				</div>
																		</li>";
																	}
																	?>
																</ul>													
														</div>
													</div>	
				            		        	<?php endif; ?>
											<?php endif; ?>									
						    			<p class="rs-disp-testimonial"><?php echo esc_html($rsw_testimonial_item["description"]); ?></p>
						    			<?php if ($instance['show_dates'] == true) : ?>
						    			<p class="rs-disp-byline"><?php echo esc_html(gmdate('d-M-Y', strtotime($rsw_testimonial_item["pubDate"]))); ?></p>
						    			<?php endif; ?>					
						    		</div>
					        	</li>
						    	<?php
						    	}
						    	?>
								<?php
								echo '</ul>';
							echo '</div>';
						}
						// OFFICE-MODE
						else { 
							$rating_score = number_format((($overall_satisfaction + $recommendation_rating + $performance_rating) / 60), 1);
							echo '<div class="office-name">' . esc_html($office) . '</div>';
							echo '<div class="header">'; 
								if (!empty($instance['display_photo'])) {
								echo '<img src="' . esc_html($logo) . '" alt="logo" class="agent-avatar_office"/>';
								}
								if ($instance['show_overall_ratings'] == True) {
									echo '<p class="profile-ratings">' .esc_html($rating_score) . '</p>'; 
									echo '<div class="overall_star_rating">';
												echo '<svg viewBox="0 0 80 16" class="overall-rating-stars-gray">';
													echo '    <path fill="#A0A0A0" d="M6.00682 0.92556C6.25927 0.16202 7.35844 0.162021 7.61088 0.92556L8.51285 3.65365C8.62575 3.99511 8.94954 4.2263 9.31488 4.2263H12.2337C13.0506 4.2263 13.3903 5.25364 12.7294 5.72553L10.368 7.41159C10.0724 7.62262 9.94877 7.99669 10.0617 8.33816L10.9636 11.0663C11.2161 11.8298 10.3268 12.4647 9.66592 11.9928L7.30453 10.3068C7.00897 10.0957 6.60874 10.0957 6.31317 10.3068L3.95178 11.9928C3.29087 12.4647 2.40162 11.8298 2.65407 11.0662L3.55604 8.33816C3.66894 7.99669 3.54526 7.62262 3.24969 7.41159L0.888301 5.72553C0.227393 5.25364 0.567055 4.2263 1.38398 4.2263H4.30282C4.66816 4.2263 4.99195 3.99511 5.10485 3.65365L6.00682 0.92556Z" />';    
													echo '    <path fill="#A0A0A0" d="M22.7822 0.92556C23.0347 0.16202 24.1338 0.162021 24.3863 0.92556L25.2882 3.65365C25.4011 3.99511 25.7249 4.2263 26.0903 4.2263H29.0091C29.826 4.2263 30.1657 5.25364 29.5048 5.72553L27.1434 7.41159C26.8478 7.62262 26.7242 7.99669 26.8371 8.33816L27.739 11.0662C27.9915 11.8298 27.1022 12.4647 26.4413 11.9928L24.0799 10.3068C23.7844 10.0957 23.3841 10.0957 23.0886 10.3068L20.7272 11.9928C20.0663 12.4647 19.177 11.8298 19.4295 11.0662L20.3314 8.33816C20.4443 7.99669 20.3206 7.62262 20.0251 7.41159L17.6637 5.72553C17.0028 5.25364 17.3424 4.2263 18.1594 4.2263H21.0782C21.4436 4.2263 21.7673 3.99511 21.8802 3.65365L22.7822 0.92556Z" />';
													echo '    <path fill="#A0A0A0" d="M39.5586 0.92556C39.811 0.16202 40.9102 0.162021 41.1626 0.92556L42.0646 3.65365C42.1775 3.99511 42.5013 4.2263 42.8666 4.2263H45.7855C46.6024 4.2263 46.9421 5.25364 46.2812 5.72553L43.9198 7.41159C43.6242 7.62262 43.5005 7.99669 43.6134 8.33816L44.5154 11.0662C44.7678 11.8298 43.8786 12.4647 43.2177 11.9928L40.8563 10.3068C40.5607 10.0957 40.1605 10.0957 39.8649 10.3068L37.5035 11.9928C36.8426 12.4647 35.9534 11.8298 36.2058 11.0662L37.1078 8.33816C37.2207 7.99669 37.097 7.62262 36.8014 7.41159L34.4401 5.72553C33.7792 5.25364 34.1188 4.2263 34.9357 4.2263H37.8546C38.2199 4.2263 38.5437 3.99511 38.6566 3.65365L39.5586 0.92556Z" />';
													echo '    <path fill="#A0A0A0" d="M56.334 0.92556C56.5864 0.16202 57.6856 0.162021 57.938 0.92556L58.84 3.65365C58.9529 3.99511 59.2767 4.2263 59.642 4.2263H62.5609C63.3778 4.2263 63.7175 5.25364 63.0565 5.72553L60.6952 7.41159C60.3996 7.62262 60.2759 7.99669 60.3888 8.33816L61.2908 11.0662C61.5432 11.8298 60.654 12.4647 59.9931 11.9928L57.6317 10.3068C57.3361 10.0957 56.9359 10.0957 56.6403 10.3068L54.2789 11.9928C53.618 12.4647 52.7288 11.8298 52.9812 11.0662L53.8832 8.33816C53.9961 7.99669 53.8724 7.62262 53.5768 7.41159L51.2154 5.72553C50.5545 5.25364 50.8942 4.2263 51.7111 4.2263H54.63C54.9953 4.2263 55.3191 3.99511 55.432 3.65365L56.334 0.92556Z" />';
													echo '    <path fill="#A0A0A0" d="M73.1103 0.92556C73.3628 0.16202 74.462 0.162021 74.7144 0.92556L75.6164 3.65365C75.7293 3.99511 76.0531 4.2263 76.4184 4.2263H79.3372C80.1542 4.2263 80.4938 5.25364 79.8329 5.72553L77.4715 7.41159C77.176 7.62262 77.0523 7.99669 77.1652 8.33816L78.0672 11.0662C78.3196 11.8298 77.4303 12.4647 76.7694 11.9928L74.408 10.3068C74.1125 10.0957 73.7123 10.0957 73.4167 10.3068L71.0553 11.9928C70.3944 12.4647 69.5051 11.8298 69.7576 11.0662L70.6596 8.33816C70.7725 7.99669 70.6488 7.62262 70.3532 7.41159L67.9918 5.72553C67.3309 5.25364 67.6706 4.2263 68.4875 4.2263H71.4063C71.7717 4.2263 72.0955 3.99511 72.2084 3.65365L73.1103 0.92556Z" />';
												echo '</svg>';
												echo '<div class="overall-rating-stars-gold" data-star="' . number_format($rating_score, 1) . '">'; 
													echo '<svg viewBox="0 0 80 16" class="overall-rating-stars-gold">';
														echo '    <path fill="#F0B64F" d="M6.00682 0.92556C6.25927 0.16202 7.35844 0.162021 7.61088 0.92556L8.51285 3.65365C8.62575 3.99511 8.94954 4.2263 9.31488 4.2263H12.2337C13.0506 4.2263 13.3903 5.25364 12.7294 5.72553L10.368 7.41159C10.0724 7.62262 9.94877 7.99669 10.0617 8.33816L10.9636 11.0663C11.2161 11.8298 10.3268 12.4647 9.66592 11.9928L7.30453 10.3068C7.00897 10.0957 6.60874 10.0957 6.31317 10.3068L3.95178 11.9928C3.29087 12.4647 2.40162 11.8298 2.65407 11.0662L3.55604 8.33816C3.66894 7.99669 3.54526 7.62262 3.24969 7.41159L0.888301 5.72553C0.227393 5.25364 0.567055 4.2263 1.38398 4.2263H4.30282C4.66816 4.2263 4.99195 3.99511 5.10485 3.65365L6.00682 0.92556Z" />';
														echo '     <path fill="#F0B64F" d="M22.7822 0.92556C23.0347 0.16202 24.1338 0.162021 24.3863 0.92556L25.2882 3.65365C25.4011 3.99511 25.7249 4.2263 26.0903 4.2263H29.0091C29.826 4.2263 30.1657 5.25364 29.5048 5.72553L27.1434 7.41159C26.8478 7.62262 26.7242 7.99669 26.8371 8.33816L27.739 11.0662C27.9915 11.8298 27.1022 12.4647 26.4413 11.9928L24.0799 10.3068C23.7844 10.0957 23.3841 10.0957 23.0886 10.3068L20.7272 11.9928C20.0663 12.4647 19.177 11.8298 19.4295 11.0662L20.3314 8.33816C20.4443 7.99669 20.3206 7.62262 20.0251 7.41159L17.6637 5.72553C17.0028 5.25364 17.3424 4.2263 18.1594 4.2263H21.0782C21.4436 4.2263 21.7673 3.99511 21.8802 3.65365L22.7822 0.92556Z" />';
														echo '    <path fill="#F0B64F" d="M39.5586 0.92556C39.811 0.16202 40.9102 0.162021 41.1626 0.92556L42.0646 3.65365C42.1775 3.99511 42.5013 4.2263 42.8666 4.2263H45.7855C46.6024 4.2263 46.9421 5.25364 46.2812 5.72553L43.9198 7.41159C43.6242 7.62262 43.5005 7.99669 43.6134 8.33816L44.5154 11.0662C44.7678 11.8298 43.8786 12.4647 43.2177 11.9928L40.8563 10.3068C40.5607 10.0957 40.1605 10.0957 39.8649 10.3068L37.5035 11.9928C36.8426 12.4647 35.9534 11.8298 36.2058 11.0662L37.1078 8.33816C37.2207 7.99669 37.097 7.62262 36.8014 7.41159L34.4401 5.72553C33.7792 5.25364 34.1188 4.2263 34.9357 4.2263H37.8546C38.2199 4.2263 38.5437 3.99511 38.6566 3.65365L39.5586 0.92556Z" />';
														echo '    <path fill="#F0B64F" d="M56.334 0.92556C56.5864 0.16202 57.6856 0.162021 57.938 0.92556L58.84 3.65365C58.9529 3.99511 59.2767 4.2263 59.642 4.2263H62.5609C63.3778 4.2263 63.7175 5.25364 63.0565 5.72553L60.6952 7.41159C60.3996 7.62262 60.2759 7.99669 60.3888 8.33816L61.2908 11.0662C61.5432 11.8298 60.654 12.4647 59.9931 11.9928L57.6317 10.3068C57.3361 10.0957 56.9359 10.0957 56.6403 10.3068L54.2789 11.9928C53.618 12.4647 52.7288 11.8298 52.9812 11.0662L53.8832 8.33816C53.9961 7.99669 53.8724 7.62262 53.5768 7.41159L51.2154 5.72553C50.5545 5.25364 50.8942 4.2263 51.7111 4.2263H54.63C54.9953 4.2263 55.3191 3.99511 55.432 3.65365L56.334 0.92556Z" />';
														echo '    <path fill="#F0B64F" d="M73.1103 0.92556C73.3628 0.16202 74.462 0.162021 74.7144 0.92556L75.6164 3.65365C75.7293 3.99511 76.0531 4.2263 76.4184 4.2263H79.3372C80.1542 4.2263 80.4938 5.25364 79.8329 5.72553L77.4715 7.41159C77.176 7.62262 77.0523 7.99669 77.1652 8.33816L78.0672 11.0662C78.3196 11.8298 77.4303 12.4647 76.7694 11.9928L74.408 10.3068C74.1125 10.0957 73.7123 10.0957 73.4167 10.3068L71.0553 11.9928C70.3944 12.4647 69.5051 11.8298 69.7576 11.0662L70.6596 8.33816C70.7725 7.99669 70.6488 7.62262 70.3532 7.41159L67.9918 5.72553C67.3309 5.25364 67.6706 4.2263 68.4875 4.2263H71.4063C71.7717 4.2263 72.0955 3.99511 72.2084 3.65365L73.1103 0.92556Z" />';
													echo '</svg>';
												echo '</div>';
									echo '</div>';
								}
								$office_url = 'https://www.realsatisfied.com/office/' . $instance['real_satisfied_id'];
								echo '<a href="' . esc_url($office_url) . '" target="_blank" class="office-profile-reviews" title="View the office Profile for ' . esc_attr($office) . '" style="text-decoration: underline;">';
								echo '<span itemprop="itemreviewed">' . esc_html($rsw_response_count) . '</span> reviews';
								echo '</a>';
							echo '</div>';
							echo '<div class="rsw-flexslider">';
							    echo '<ul class="rs-slides">';							
						    		$count = 0;
									for ($x = 0; $x < count($rsw_testimonials_array); $x++) {
									$count++;
									$rsw_testimonial_item = $rsw_testimonials_array[$x];
									?>
										<li style="text-align: left;">
											<div class="testimonial">									
												<div class="review_for">
													<?php if (!empty($rsw_testimonial_item['avatar'])): ?>
														<img src="<?php echo esc_html($rsw_testimonial_item['avatar']); ?>" alt="Agent Avatar" class="agent-avatar"style="width: 40px; height: 40px; border-radius: 50%;" />
													<?php endif; ?>
													<div class="review-text">
														 <p class="review-prefix">Review for</p>
														 <p class="agent-name"><?php echo esc_html($rsw_testimonial_item['display_name']); ?></p>
													 </div>										 
												</div>													
												<div class="name_customer_type">
													<?php echo esc_html($rsw_testimonial_item["title"]); ?>
													<span><?php echo esc_html($rsw_testimonial_item["customer_type"]); ?></span>
												</div>													
											    <?php if ($instance['display_ratings'] == true) : ?>
													<?php
													$satisfaction = $rsw_testimonial_item['satisfaction'];
    												$performance = $rsw_testimonial_item['performance'];
    												$recommendation = $rsw_testimonial_item['recommendation'];
    												$overall_rating = number_format((($satisfaction + $recommendation + $performance) / 60), 1);
    												?>
													<?php if ($overall_rating > 0) : ?>
														<div class="rating">
															<?php
															echo '<p class="testimonials-profile-ratings">' . esc_html($overall_rating) . '</p>';
															echo '<div class="star-rating-testimonial">';
																echo '<div class="survey_measure_stars">';								
																		echo '<svg viewBox="0 0 80 16" class="overall-rating-stars-gray">';
																			echo '    <path fill="#A0A0A0" d="M6.00682 0.92556C6.25927 0.16202 7.35844 0.162021 7.61088 0.92556L8.51285 3.65365C8.62575 3.99511 8.94954 4.2263 9.31488 4.2263H12.2337C13.0506 4.2263 13.3903 5.25364 12.7294 5.72553L10.368 7.41159C10.0724 7.62262 9.94877 7.99669 10.0617 8.33816L10.9636 11.0663C11.2161 11.8298 10.3268 12.4647 9.66592 11.9928L7.30453 10.3068C7.00897 10.0957 6.60874 10.0957 6.31317 10.3068L3.95178 11.9928C3.29087 12.4647 2.40162 11.8298 2.65407 11.0662L3.55604 8.33816C3.66894 7.99669 3.54526 7.62262 3.24969 7.41159L0.888301 5.72553C0.227393 5.25364 0.567055 4.2263 1.38398 4.2263H4.30282C4.66816 4.2263 4.99195 3.99511 5.10485 3.65365L6.00682 0.92556Z" />';    
																			echo '    <path fill="#A0A0A0" d="M22.7822 0.92556C23.0347 0.16202 24.1338 0.162021 24.3863 0.92556L25.2882 3.65365C25.4011 3.99511 25.7249 4.2263 26.0903 4.2263H29.0091C29.826 4.2263 30.1657 5.25364 29.5048 5.72553L27.1434 7.41159C26.8478 7.62262 26.7242 7.99669 26.8371 8.33816L27.739 11.0662C27.9915 11.8298 27.1022 12.4647 26.4413 11.9928L24.0799 10.3068C23.7844 10.0957 23.3841 10.0957 23.0886 10.3068L20.7272 11.9928C20.0663 12.4647 19.177 11.8298 19.4295 11.0662L20.3314 8.33816C20.4443 7.99669 20.3206 7.62262 20.0251 7.41159L17.6637 5.72553C17.0028 5.25364 17.3424 4.2263 18.1594 4.2263H21.0782C21.4436 4.2263 21.7673 3.99511 21.8802 3.65365L22.7822 0.92556Z" />';
																			echo '    <path fill="#A0A0A0" d="M39.5586 0.92556C39.811 0.16202 40.9102 0.162021 41.1626 0.92556L42.0646 3.65365C42.1775 3.99511 42.5013 4.2263 42.8666 4.2263H45.7855C46.6024 4.2263 46.9421 5.25364 46.2812 5.72553L43.9198 7.41159C43.6242 7.62262 43.5005 7.99669 43.6134 8.33816L44.5154 11.0662C44.7678 11.8298 43.8786 12.4647 43.2177 11.9928L40.8563 10.3068C40.5607 10.0957 40.1605 10.0957 39.8649 10.3068L37.5035 11.9928C36.8426 12.4647 35.9534 11.8298 36.2058 11.0662L37.1078 8.33816C37.2207 7.99669 37.097 7.62262 36.8014 7.41159L34.4401 5.72553C33.7792 5.25364 34.1188 4.2263 34.9357 4.2263H37.8546C38.2199 4.2263 38.5437 3.99511 38.6566 3.65365L39.5586 0.92556Z" />';
																			echo '    <path fill="#A0A0A0" d="M56.334 0.92556C56.5864 0.16202 57.6856 0.162021 57.938 0.92556L58.84 3.65365C58.9529 3.99511 59.2767 4.2263 59.642 4.2263H62.5609C63.3778 4.2263 63.7175 5.25364 63.0565 5.72553L60.6952 7.41159C60.3996 7.62262 60.2759 7.99669 60.3888 8.33816L61.2908 11.0662C61.5432 11.8298 60.654 12.4647 59.9931 11.9928L57.6317 10.3068C57.3361 10.0957 56.9359 10.0957 56.6403 10.3068L54.2789 11.9928C53.618 12.4647 52.7288 11.8298 52.9812 11.0662L53.8832 8.33816C53.9961 7.99669 53.8724 7.62262 53.5768 7.41159L51.2154 5.72553C50.5545 5.25364 50.8942 4.2263 51.7111 4.2263H54.63C54.9953 4.2263 55.3191 3.99511 55.432 3.65365L56.334 0.92556Z" />';
																			echo '    <path fill="#A0A0A0" d="M73.1103 0.92556C73.3628 0.16202 74.462 0.162021 74.7144 0.92556L75.6164 3.65365C75.7293 3.99511 76.0531 4.2263 76.4184 4.2263H79.3372C80.1542 4.2263 80.4938 5.25364 79.8329 5.72553L77.4715 7.41159C77.176 7.62262 77.0523 7.99669 77.1652 8.33816L78.0672 11.0662C78.3196 11.8298 77.4303 12.4647 76.7694 11.9928L74.408 10.3068C74.1125 10.0957 73.7123 10.0957 73.4167 10.3068L71.0553 11.9928C70.3944 12.4647 69.5051 11.8298 69.7576 11.0662L70.6596 8.33816C70.7725 7.99669 70.6488 7.62262 70.3532 7.41159L67.9918 5.72553C67.3309 5.25364 67.6706 4.2263 68.4875 4.2263H71.4063C71.7717 4.2263 72.0955 3.99511 72.2084 3.65365L73.1103 0.92556Z" />';
																		echo '</svg>';
																		echo '<div class="overall-rating-stars-gold" data-star="' . number_format($overall_rating, 1) . '">';
																			echo '<svg viewBox="0 0 80 16" class="overall-rating-stars-gold">';
																				echo '    <path fill="#F0B64F" d="M6.00682 0.92556C6.25927 0.16202 7.35844 0.162021 7.61088 0.92556L8.51285 3.65365C8.62575 3.99511 8.94954 4.2263 9.31488 4.2263H12.2337C13.0506 4.2263 13.3903 5.25364 12.7294 5.72553L10.368 7.41159C10.0724 7.62262 9.94877 7.99669 10.0617 8.33816L10.9636 11.0663C11.2161 11.8298 10.3268 12.4647 9.66592 11.9928L7.30453 10.3068C7.00897 10.0957 6.60874 10.0957 6.31317 10.3068L3.95178 11.9928C3.29087 12.4647 2.40162 11.8298 2.65407 11.0662L3.55604 8.33816C3.66894 7.99669 3.54526 7.62262 3.24969 7.41159L0.888301 5.72553C0.227393 5.25364 0.567055 4.2263 1.38398 4.2263H4.30282C4.66816 4.2263 4.99195 3.99511 5.10485 3.65365L6.00682 0.92556Z" />';
																				echo '     <path fill="#F0B64F" d="M22.7822 0.92556C23.0347 0.16202 24.1338 0.162021 24.3863 0.92556L25.2882 3.65365C25.4011 3.99511 25.7249 4.2263 26.0903 4.2263H29.0091C29.826 4.2263 30.1657 5.25364 29.5048 5.72553L27.1434 7.41159C26.8478 7.62262 26.7242 7.99669 26.8371 8.33816L27.739 11.0662C27.9915 11.8298 27.1022 12.4647 26.4413 11.9928L24.0799 10.3068C23.7844 10.0957 23.3841 10.0957 23.0886 10.3068L20.7272 11.9928C20.0663 12.4647 19.177 11.8298 19.4295 11.0662L20.3314 8.33816C20.4443 7.99669 20.3206 7.62262 20.0251 7.41159L17.6637 5.72553C17.0028 5.25364 17.3424 4.2263 18.1594 4.2263H21.0782C21.4436 4.2263 21.7673 3.99511 21.8802 3.65365L22.7822 0.92556Z" />';
																				echo '    <path fill="#F0B64F" d="M39.5586 0.92556C39.811 0.16202 40.9102 0.162021 41.1626 0.92556L42.0646 3.65365C42.1775 3.99511 42.5013 4.2263 42.8666 4.2263H45.7855C46.6024 4.2263 46.9421 5.25364 46.2812 5.72553L43.9198 7.41159C43.6242 7.62262 43.5005 7.99669 43.6134 8.33816L44.5154 11.0662C44.7678 11.8298 43.8786 12.4647 43.2177 11.9928L40.8563 10.3068C40.5607 10.0957 40.1605 10.0957 39.8649 10.3068L37.5035 11.9928C36.8426 12.4647 35.9534 11.8298 36.2058 11.0662L37.1078 8.33816C37.2207 7.99669 37.097 7.62262 36.8014 7.41159L34.4401 5.72553C33.7792 5.25364 34.1188 4.2263 34.9357 4.2263H37.8546C38.2199 4.2263 38.5437 3.99511 38.6566 3.65365L39.5586 0.92556Z" />';
																				echo '    <path fill="#F0B64F" d="M56.334 0.92556C56.5864 0.16202 57.6856 0.162021 57.938 0.92556L58.84 3.65365C58.9529 3.99511 59.2767 4.2263 59.642 4.2263H62.5609C63.3778 4.2263 63.7175 5.25364 63.0565 5.72553L60.6952 7.41159C60.3996 7.62262 60.2759 7.99669 60.3888 8.33816L61.2908 11.0662C61.5432 11.8298 60.654 12.4647 59.9931 11.9928L57.6317 10.3068C57.3361 10.0957 56.9359 10.0957 56.6403 10.3068L54.2789 11.9928C53.618 12.4647 52.7288 11.8298 52.9812 11.0662L53.8832 8.33816C53.9961 7.99669 53.8724 7.62262 53.5768 7.41159L51.2154 5.72553C50.5545 5.25364 50.8942 4.2263 51.7111 4.2263H54.63C54.9953 4.2263 55.3191 3.99511 55.432 3.65365L56.334 0.92556Z" />';
																				echo '    <path fill="#F0B64F" d="M73.1103 0.92556C73.3628 0.16202 74.462 0.162021 74.7144 0.92556L75.6164 3.65365C75.7293 3.99511 76.0531 4.2263 76.4184 4.2263H79.3372C80.1542 4.2263 80.4938 5.25364 79.8329 5.72553L77.4715 7.41159C77.176 7.62262 77.0523 7.99669 77.1652 8.33816L78.0672 11.0662C78.3196 11.8298 77.4303 12.4647 76.7694 11.9928L74.408 10.3068C74.1125 10.0957 73.7123 10.0957 73.4167 10.3068L71.0553 11.9928C70.3944 12.4647 69.5051 11.8298 69.7576 11.0662L70.6596 8.33816C70.7725 7.99669 70.6488 7.62262 70.3532 7.41159L67.9918 5.72553C67.3309 5.25364 67.6706 4.2263 68.4875 4.2263H71.4063C71.7717 4.2263 72.0955 3.99511 72.2084 3.65365L73.1103 0.92556Z" />';
																			echo '</svg>';
																		echo '</div>';
																echo '</div>';
															echo'</div>';
															?>
															<!-- Dropdown -->
															<div class="survey_overall_dropdown">
																<a class="dropdown-icon" href="#" role="button" data-bs-toggle="dropdown" data-bs-trigger="click" aria-expanded="false"> </a>
																	<ul class="dropdown-menu">
																		<?php
																		$metrics = ['Satisfaction' => $satisfaction,'Performance' => $performance,'Recommendation' => $recommendation];
																		foreach ($metrics as $label => $metric) {
																			list($score) = rsrw_rating_star_score($metric);															
																			$li = "<li>
																					<div class='banner-rating d-flex justify-content-between align-items-center'>
																						<div class='survey_measure_text'>{$label}</div>
																						<div class='score'>
																							<span class='survey_measure_rating'>{$score}</span>
																						</div>
																						<div class='dropdown_stars'>";
																						echo wp_kses_post($li);
																						echo wp_kses_post( rsrw_obtain_single_gold_star() );
																						echo "</div>
																					</div>
																			</li>";
																		}
																		?>
																	</ul>
															</div>
														</div>	
				            			        	<?php endif; ?>
												<?php endif; ?>
																	
												<p class="rs-disp-testimonial"><?php echo esc_html($rsw_testimonial_item["description"]); ?></p>
												<?php if ($instance['show_dates'] == true) : ?>
												<p class="rs-disp-byline"><?php echo esc_html(gmdate('d-M-Y', strtotime($rsw_testimonial_item["pubDate"]))); ?></p>
												<?php endif; ?>
											</div>
										</li>
									<?php
									}
									?>
									<?php
								echo '</ul>';
							echo '</div>';
							// echo '</ul></div>';
						} 						
					}
				}
				?>
				<input type="hidden" name="speed" id="speed" value="<?php echo esc_attr($instance['speed']); ?>">
				<input type="hidden" name="animation_type" id ="animation_type" value="<?php echo esc_attr($instance['animation_type']); ?>">
				<input type="hidden" name="auto_animate" id= "auto_animate" value="<?php echo esc_attr($instance['auto_animate']); ?>">
				<input type="hidden" name="display_arrows" id= "display_arrows" value="<?php echo intval($instance['display_arrows']); ?>">
				<?php
				
				if ($instance['show_rs_banner'] == True) {
					$rs_banner ='<div class="footer">						
					<a href="https://www.realsatisfied.com/" target="_blank" rel="noopener noreferrer" class="footer-banner">
					    <img src="' . plugins_url('images/rs-footer.svg', __FILE__) . '" alt="RealSatisfied Banner">
					</a>
					</div>';
					echo wp_kses_post($rs_banner);
				}				
				echo wp_kses_post( $after_widget );				
			} 
			else {
				// Unable to retrieve feed or cached content
				echo wp_kses_post( $before_widget );
				echo wp_kses_post( $before_title ) . esc_html('RealSatisfied Plugin') . wp_kses_post($after_title);
				echo '<p>Cannot Read Feed. Please verify the vanity key is correct.</p>';
				echo esc_html($rsw_rss_feed_source->get_error_message());
				echo wp_kses_post($after_widget);
			}
		} 
		else {
			echo wp_kses_post( $before_widget );
			echo wp_kses_post( $before_title ) . esc_html('RealSatisfied Plugin') . wp_kses_post($after_title);
			echo '<p>No Vanity Key Set.</p>';
			echo wp_kses_post($after_widget);
		}
	}
}

// overall ratings
function rsrw_rating_star_score($rating) {
	$rating_score = number_format($rating / 20, 1);
	return [$rating_score];
}
function rsrw_register_review_widget() { 
    register_widget("RSRW_Real_Satisfied_Review_Widget");
}
add_action('widgets_init', 'rsrw_register_review_widget');

// Function to limit the number of words displayed in a string
function rsrw_limit_words($string, $word_limit) {
    $words = explode(" ",$string);
    return implode(" ",array_splice($words,0,$word_limit));
}

// Add thickbox support
function rsrw_add_thickbox_support() {
   add_thickbox();
}
add_action('init', 'rsrw_add_thickbox_support');

// Enqueue custom styles and scripts
function rsrw_enqueue_styles_and_scripts() {
    wp_enqueue_script('flexslider', plugins_url('/flexslider/jquery.flexslider.js', __FILE__), array('jquery'), '2.7.2', true);
    wp_enqueue_style('flexslider-css', plugins_url('/flexslider/flexslider.css', __FILE__), array() ,'2.7.2');
    wp_enqueue_style('rsw-styles', plugins_url('/realsatisfied.css', __FILE__), array(),filemtime( plugin_dir_path(__FILE__) . 'realsatisfied.css'));	
	wp_enqueue_style('bootstrap-css', plugins_url('/bootstrap.min.css', __FILE__), array(), '5.3.3');
    wp_enqueue_script('bootstrap-js', plugins_url('js/bootstrap.bundle.min.js', __FILE__), array('jquery'), '5.3.3', true);
	
	// Enqueue realsatisfied.js
    wp_enqueue_script('realsatisfied-script', plugins_url('js/realsatisfied.js', __FILE__), array('jquery'), '1.0.0', true);

    // Localize script to pass PHP values to JS
    wp_localize_script('realsatisfied-script', 'rsw_params', array(
        'speed'          => 5,
        'animation_type' => 'slide',
        'auto_animate'   => true,
		'display_arrows' => true        
    ));
	
	// wp_localize_script('realsatisfied-script', 'rsw_params', array(
    //     'speed' => !empty($instance['speed']) ? esc_js($instance['speed']) : 5,
    //     'animation_type' => !empty($instance['animation_type']) ? esc_js($instance['animation_type']) : 'fade',
    //     'auto_animate' => !empty($instance['auto_animate']) ? 'true' : 'false',
    //     'display_arrows' => !empty($instance['display_arrows']) ? 'true' : 'false'
	// ));	
	
}
add_action('wp_enqueue_scripts', 'rsrw_enqueue_styles_and_scripts');

// Add a button to the admin section to clear the feed cache
function rsrw_clear_cache_button() {
	echo '<a href="#ajaxthing" class="myajax button-secondary">Clear the Testimonial Cache</a>';
}

// Clear the feed cache
function rsrw_enqueue_clear_feed_cache_script($hook) {
    if ($hook !== 'toplevel_page_realsatisfied') {
        return;
    }
    wp_register_script('rsw-clear-cache-script', '', ['jquery'], '2.0.0', true);
    wp_enqueue_script('rsw-clear-cache-script');
    
    $inline_script = "
    jQuery(document).ready(function($) {
        $('.myajax').click(function() {
            var data = {
                action: 'rsw_clear_feed_cache'
            };
            $.post(ajaxurl, data, function(response) {
                alert(response);
            });
        });
    });
    ";
    wp_add_inline_script('rsw-clear-cache-script', $inline_script);
}
add_action('admin_enqueue_scripts', 'rsrw_enqueue_clear_feed_cache_script');

// Clear the feed cache
function rsrw_clear_feed_cache_callback() {
    global $wpdb; // this is how you get access to the database
    function cache_transient_1($a) {return 1;}
    add_filter('wp_feed_cache_transient_lifetime', 'cache_transient_1');
    $rsw_rss = fetch_feed('http://rss.realsatisfied.com/rss/v3/agent/detailed/' . $rsw_real_satisfied_id . '/page=1&source=wp_widget');
    function cache_transient_2($a) {return 43200;}
    add_filter('wp_feed_cache_transient_lifetime', 'cache_transient_2');
    $response = 'Cache has been cleared.';
    echo esc_html($response);
    exit(); // this is required to return a proper result & exit is faster than die();
}
add_action('wp_ajax_rsw_clear_feed_cache', 'rsrw_clear_feed_cache_callback');

// function to fetch channel tag data with a fallback
function rsrw_obtain_channel_tag_data($rss_feed, $namespace, $tag, $default = '') {
    $tag_data = $rss_feed->get_channel_tags($namespace, $tag);
    return (!empty($tag_data) && isset($tag_data[0]['data'])) ? $tag_data[0]['data'] : $default;
}

//  function to fetch item tag data with a fallback
function rsrw_obtain_item_tag_data($rss_item, $namespace, $tag, $default = null) {
    $tag_data = $rss_item->get_item_tags($namespace, $tag);
    return (is_array($tag_data) && isset($tag_data[0]['data'])) ? $tag_data[0]['data'] : $default;
}

function rsrw_obtain_single_gold_star() {
    return '
    <svg xmlns="http://www.w3.org/2000/svg" width="20" height="20" viewBox="0 0 24 24" fill="#F0B64F">
		<path d="M8.39654 1.32487C8.76118 0.225041 10.3489 0.225042 10.7135 1.32487L12.0164 5.25452C12.1794 5.74638 12.6471 6.0794 13.1748 6.0794H17.391C18.571 6.0794 19.0616 7.55921 18.1069 8.23895L14.696 10.6676C14.2691 10.9716 14.0905 11.5104 14.2535 12.0023L15.5564 15.9319C15.921 17.0318 14.6366 17.9463 13.6819 17.2666L10.271 14.8379C9.84408 14.534 9.26597 14.534 8.83904 14.8379L5.42814 17.2666C4.47349 17.9463 3.18903 17.0318 3.55367 15.9319L4.85652 12.0023C5.01959 11.5104 4.84094 10.9716 4.41401 10.6676L1.00311 8.23895C0.0484673 7.55921 0.539091 6.0794 1.7191 6.0794H5.9352C6.46292 6.0794 6.93062 5.74638 7.09369 5.25452L8.39654 1.32487Z" fill="#F0B64F"/>
    </svg>';
}

function rsrw_allow_svg_tags_in_kses($tags) {
    $tags['svg'] = [
        'xmlns' => true,
        'width' => true,
        'height' => true,
        'viewBox' => true,
        'fill' => true,
    ];
    $tags['path'] = [
        'd' => true,
        'fill' => true,
    ];
    return $tags;
}
add_filter('wp_kses_allowed_html', 'rsrw_allow_svg_tags_in_kses', 10, 1);